@@ -1,7 +1,7 @@
 # flake8: noqa
 from ._version import __version_info__, __version__
 from .connection import Config, Connection
-from .runners import Remote, Result
+from .runners import Remote, RemoteShell, Result
 from .group import Group, SerialGroup, ThreadingGroup, GroupResult
 from .tasks import task, Task
 from .executor import Executor
